@@ -31,9 +31,9 @@ class PriceMapper:
         result.datum.from_datetime(price_datetime)
         assert isinstance(result.datum, Datum)
 
-        #result.namespace = entity.namespace
-        #result.symbol = entity.symbol
-        result.symbol = SecuritySymbol(entity.namespace, entity.symbol)
+        # result.symbol = SecuritySymbol(entity.security.namespace, entity.security.symbol)
+        mnemonic = entity.security.ledger_symbol if entity.security.ledger_symbol else entity.security.symbol
+        result.symbol = SecuritySymbol(entity.security.namespace, mnemonic)
 
         # Value
         value = Decimal(entity.value) / Decimal(entity.denom)
@@ -58,10 +58,9 @@ class PriceMapper:
         # Symbol
         entity.security_id = model.security_id
         # properly mapped symbols have a namespace, except for the US markets
-        # todo: Remove symbol from Price table, normalize.
-        if model.symbol.namespace:
-            entity.namespace = model.symbol.namespace.upper()
-        entity.symbol = model.symbol.mnemonic.upper()
+        # if model.symbol.namespace:
+        #     entity.namespace = model.symbol.namespace.upper()
+        # entity.symbol = model.symbol.mnemonic.upper()
 
         assert isinstance(model.value, Decimal)
         # Find number of decimal places
